==> haskell-config-schema-1.3.0.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-schema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 config-schema
version:              1.3.0.0
visibility:           public
id:                   config-schema-1.3.0.0-7a6S1wH2SsOIMjt9diQNTl
key:                  config-schema-1.3.0.0-7a6S1wH2SsOIMjt9diQNTl
license:              ISC
copyright:            Eric Mertens 2017
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-schema
synopsis:             Schema definitions for the config-value package
description:
    This package makes it possible to define schemas for use when
    loading configuration files using the config-value format.
    These schemas can be used to process a configuration file into
    a Haskell value or to automatically generate documentation for
    the file format.

category:             Language
abi:                  855c2504b3a1b3d2ee93a9ce65ab1e1c
exposed:              True
exposed-modules:
    Config.Schema Config.Schema.Docs Config.Schema.Load
    Config.Schema.Load.Error Config.Schema.Spec Config.Schema.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/config-schema-1.3.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/config-schema-1.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-schema
hs-libraries:         HSconfig-schema-1.3.0.0-7a6S1wH2SsOIMjt9diQNTl
depends:
    base-4.15.1.0 config-value-0.8.3-3pmzeYU8Vb25WTAZFoPyxS
    containers-0.6.4.1 free-5.1.10-E9Q8boeuiuSDb7lvFfiZ46
    kan-extensions-5.2.5-KZefhcNVAvrH3rVJY8ZjGh pretty-1.1.3.6
    semigroupoids-5.3.7-7G5akXQDnvR8hF2RGsWdKt text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-config-schema/html/config-schema.haddock

haddock-html:         /usr/share/doc/haskell-config-schema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-schema-1.3.0.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-schema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 config-schema
version:              1.3.0.0
visibility:           public
id:                   config-schema-1.3.0.0-ES6CAdrsn6c6WiGMEWLBek
key:                  config-schema-1.3.0.0-ES6CAdrsn6c6WiGMEWLBek
license:              ISC
copyright:            Eric Mertens 2017
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-schema
synopsis:             Schema definitions for the config-value package
description:
    This package makes it possible to define schemas for use when
    loading configuration files using the config-value format.
    These schemas can be used to process a configuration file into
    a Haskell value or to automatically generate documentation for
    the file format.

category:             Language
abi:                  97327fb36d75332ced0e4dc372a55e63
exposed:              True
exposed-modules:
    Config.Schema Config.Schema.Docs Config.Schema.Load
    Config.Schema.Load.Error Config.Schema.Spec Config.Schema.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/config-schema-1.3.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/config-schema-1.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-schema
hs-libraries:         HSconfig-schema-1.3.0.0-ES6CAdrsn6c6WiGMEWLBek
depends:
    base-4.15.1.0 config-value-0.8.3-3pmzeYU8Vb25WTAZFoPyxS
    containers-0.6.4.1 free-5.1.10-7C6NAAeSiKJ8iNMmNxgt1s
    kan-extensions-5.2.5-8y9v063ZY3UBGonMRFzsOL pretty-1.1.3.6
    semigroupoids-5.3.7-DcMVPlf7Tb04W6WS8J0hYE text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-config-schema/html/config-schema.haddock

haddock-html:         /usr/share/doc/haskell-config-schema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
